@@ -99,29 +99,14 @@ class BaseFinderStorage(PipelineStorage):
                 except OSError:
                     pass
 
-    def match_location(self, name, path, prefix=None):
-        if prefix:
-            if prefix != name[:len(prefix)]:
-                return None
-            prefix = "%s%s" % (prefix, os.sep)
-            name = name[len(prefix):]
-
-        norm_path = os.path.normpath(path)
-        norm_name = os.path.normpath(name)
-
-        if norm_path == norm_name:
-            return name
-        if os.path.splitext(norm_path)[0] == os.path.splitext(norm_name)[0]:
-            return name
-        return None
-
     def find_storage(self, name):
         for finder in self.finders.get_finders():
-            for path, storage in finder.list([]):
-                prefix = getattr(storage, 'prefix', None)
-                matched_path = self.match_location(name, path, prefix)
-                if matched_path:
-                    return matched_path, storage
+            path = finder.find(name)
+            if path:
+                for storage_root, storage in finder.storages.items():
+                    if path.startswith(storage_root):
+                        return path, storage
+
         raise ValueError("The file '%s' could not be found with %r." % (name, self))
 
     def _open(self, name, mode="rb"):
